@@ -37,7 +37,8 @@ class AuditEvent(CloudEvent):  # type: ignore
         fhir_audit_event.recorded = self._get_event_recorded()
         user_agent = self._get_user_agent(data)
         patient_agent = self._get_patient_agent(data)
-        fhir_audit_event.agent = [user_agent, patient_agent]
+        organization_agent = self._get_organization_agent(data)
+        fhir_audit_event.agent = [user_agent, patient_agent, organization_agent]
         fhir_audit_event.source = self._get_audit_event_source(data)
         fhir_audit_event.entity = [self._get_audit_event_entity(data)]
         return fhir_audit_event
@@ -78,6 +79,15 @@ class AuditEvent(CloudEvent):  # type: ignore
         ]
         return user_agent
 
+    def _get_organization_agent(self, data: Audit) -> AuditEventAgent:
+        organization_agent = AuditEventAgent()
+        organization_agent.requestor = False
+        organization_agent.altId = data.client_slug
+        organization_agent.who = FHIRReference(jsondict={
+            "reference": f"Organization/{data.client_slug}"
+        })
+        return organization_agent
+
     def _get_event_type(self, data: Audit) -> Coding:
         event_type = Coding()
         event_type.code = data.action_type
