@@ -4,8 +4,7 @@ from helix_events_sdk.schemas.audit_enums import AuditAction, AuditActionType, R
 class Audit:
     def __init__(
         self, patient_id: str, user_id: str, user_role: str, ip_address: str,
-        client_slug: str,
-        action: AuditAction, action_type: AuditActionType,
+        client_slug: str, action: AuditAction, action_type: AuditActionType,
         accessed_resource: ResourceType
     ):
         self.patient_id = patient_id
